import { useState, useEffect } from "react";
import { useParams, useNavigate } from "react-router-dom";
import { useAuth } from "../contexts/AuthContext";
import { getUserProfile, getUserReviews } from "../services/supabase";
import {
  FiEdit,
  FiSettings,
  FiCalendar,
  FiStar,
  FiFilm,
  FiTv,
  FiLogOut,
} from "react-icons/fi";
import ReviewCard from "../components/reviews/ReviewCard";
import RatingChart from "../components/reviews/RatingChart";

function ProfilePage() {
  const { userId } = useParams();
  const navigate = useNavigate();
  const { currentUser, userProfile } = useAuth();
  const [profile, setProfile] = useState(null);
  const [reviews, setReviews] = useState([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  useEffect(() => {
    const loadProfile = async () => {
      try {
        setLoading(true);
        setError(null);
        
        // Если userId не указан, показываем профиль текущего пользователя
        const targetUserId = userId || currentUser?.id;
        if (!targetUserId) {
          navigate('/login');
          return;
        }

        const profileData = await getUserProfile(targetUserId);
        setProfile(profileData);

        const reviewsData = await getUserReviews(targetUserId);
        setReviews(reviewsData);
      } catch (err) {
        setError("Ошибка при загрузке профиля");
        console.error("Error loading profile:", err);
      } finally {
        setLoading(false);
      }
    };

    loadProfile();
  }, [userId, currentUser, navigate]);

  if (loading) {
    return (
      <div className="pt-20 container-custom py-12">
        <div className="animate-pulse">
          <div className="h-32 bg-campfire-charcoal rounded-lg mb-6"></div>
          <div className="space-y-4">
            <div className="h-4 bg-campfire-charcoal rounded w-1/4"></div>
            <div className="h-4 bg-campfire-charcoal rounded w-1/2"></div>
          </div>
        </div>
      </div>
    );
  }

  if (error) {
    return (
      <div className="pt-20 container-custom py-12">
        <div className="bg-status-error bg-opacity-20 text-status-error p-6 rounded-lg">
          <h2 className="text-xl font-bold mb-2">Ошибка</h2>
          <p>{error}</p>
        </div>
      </div>
    );
  }

  if (!profile) {
    return (
      <div className="pt-20 container-custom py-12">
        <div className="bg-status-error bg-opacity-20 text-status-error p-6 rounded-lg">
          <h2 className="text-xl font-bold mb-2">Профиль не найден</h2>
          <p>Пользователь с таким ID не существует.</p>
        </div>
      </div>
    );
  }

  const isOwnProfile = currentUser?.id === profile.id;

  return (
    <div className="pt-20 container-custom py-12">
      <div className="bg-campfire-charcoal rounded-lg overflow-hidden">
        {/* Заголовок профиля */}
        <div className="relative h-48 bg-gradient-to-r from-campfire-amber to-campfire-ember">
          {profile.profile_picture && (
            <img
              src={profile.profile_picture}
              alt={profile.username}
              className="absolute -bottom-16 left-8 w-32 h-32 rounded-full border-4 border-campfire-charcoal object-cover"
            />
          )}
        </div>

        <div className="pt-20 px-8 pb-8">
          <div className="flex justify-between items-start mb-6">
            <div>
              <h1 className="text-3xl font-bold mb-2">{profile.username}</h1>
              <p className="text-campfire-ash">
                {profile.is_critic ? "Критик" : "Пользователь"}
              </p>
            </div>
            {isOwnProfile && (
              <button
                onClick={() => navigate('/settings')}
                className="btn-secondary"
              >
                Редактировать профиль
              </button>
            )}
          </div>

          {profile.bio && (
            <div className="mb-8">
              <h2 className="text-xl font-bold mb-2">О себе</h2>
              <p className="text-campfire-light">{profile.bio}</p>
            </div>
          )}

          {/* Отзывы пользователя */}
          <div>
            <h2 className="text-2xl font-bold mb-4">Отзывы</h2>
            {reviews.length === 0 ? (
              <p className="text-campfire-ash">Пока нет отзывов</p>
            ) : (
              <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
                {reviews.map((review) => (
                  <div key={review.id} className="card p-4">
                    <div className="flex items-center mb-4">
                      <img
                        src={review.media.poster_url}
                        alt={review.media.title}
                        className="w-16 h-24 object-cover rounded-lg mr-4"
                      />
                      <div>
                        <h3 className="font-bold">{review.media.title}</h3>
                        <p className="text-sm text-campfire-ash">
                          {review.media.type === 'movie' ? 'Фильм' : 
                           review.media.type === 'series' ? 'Сериал' : 'Игра'}
                        </p>
                      </div>
                    </div>
                    <p className="text-sm mb-4 line-clamp-3">{review.content}</p>
                    <button
                      onClick={() => navigate(`/media/${review.media_id}`)}
                      className="btn-secondary w-full"
                    >
                      Читать полностью
                    </button>
                  </div>
                ))}
              </div>
            )}
          </div>
        </div>
      </div>
    </div>
  );
}

export default ProfilePage;
